/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.maven.plugins.as.common;

/**
 * JbossAsBaseDelegate
 * 
 * Generic Support for JBossAS Mojos
 * 
 * @author <a href="mailto:andrew.rubinger@jboss.org">ALR</a>
 * @version $Revision: $
 */
public abstract class JbossAsBaseDelegate
{
   // Class Members

   protected static final String ENV_VAR_JBOSS_HOME = "JBOSS_HOME";

   private static String jbossHome;

   // Functional Methods

   /**
    * Ensure $JBOSS_HOME is defined
    */
   public void checkJbossHome()
   {
      // Ensure Environment Variable JBOSS_HOME is set
      if (this.getJbossHome() == null || this.getJbossHome().equals(""))
      {
         String errorMessage = "Environment Variable \"" + JbossAsBaseDelegate.ENV_VAR_JBOSS_HOME
               + "\" must be set before running the plugin.";
         throw new RuntimeException(errorMessage, new IllegalStateException(errorMessage));
      }
   }

   // Accessors / Mutators

   public String getJbossHome()
   {
      // Set if appropriate
      if (JbossAsBaseDelegate.jbossHome == null || JbossAsBaseDelegate.jbossHome.equals(""))
      {
         JbossAsBaseDelegate.jbossHome = System.getenv(JbossAsBaseDelegate.ENV_VAR_JBOSS_HOME);
      }

      return JbossAsBaseDelegate.jbossHome;
   }
}
